#!/bin/bash
# http://qjackctl.sourceforge.net/
# 
# build deps: ImageMagick fakeroot
#
# script by : til <rob DOT til DOT freedman AT googlemail DOT com>
REPO=http://zenwalk.pinguix.com/user-accounts/tilderb
set -x -e -u
#
# qjackctl
version='0.3.6'

build=${build:-'64.1'}
arch=${arch:-i486}
cpu=${cpu:-i686}

pkgname=qjackctl-$version
package=$pkgname-$arch-$build

PKG_DEP="alsa-lib,cxxlibs,expat,fontconfig,freetype,gcc,glib2,jack,libICE,libSM,libX11,libXau,libXdmcp,libXext,libXrender,libpng,libxcb,portaudio,qt,util-linux-ng,zlib"
PKG_SRC="$REPO/extra/xap/qjackctl/build-qjackctl.sh
http://prdownloads.sourceforge.net/qjackctl/qjackctl-$version.tar.gz?download"

# build root
CWD=`pwd`
TMP=${TMP:-$CWD}
SRC=$TMP/$pkgname
PKG=$TMP/$package
#
test -d $PKG && rm -fr $PKG
test -d $SRC && rm -fr $SRC

mkdir -p $PKG/{install,usr/{doc,src}/$pkgname}
#
tar xzf $CWD/$pkgname.tar.gz -C $TMP
cd $SRC
# helperline
./configure --help >$CWD/configure-help

sed -i "s:share/man:man:g" Makefile.in

CFLAGS="-O2 -march=$arch -mtune=$cpu " \
CXXFLAGS="-O2 -march=$arch -mtune=$cpu " \
  ./configure \
   --prefix=/usr \
   --mandir=/usr/man \
   --sysconfdir=/etc \
   --localstatedir=/var

make
make install DESTDIR=$PKG
# helperline
(cd $PKG; find .  ) >$CWD/make.installed

# docs
cp -a AUTHORS COPYING ChangeLog README TODO \
   $PKG/usr/doc/$pkgname

cd $PKG
# man page
gzip -9 usr/man/man1/qjackctl.1

# strip symbols
strip --strip-unneeded usr/bin/qjackctl

# icons
for size in 16x16 24x24 32x32 48x48; do
  mkdir -p usr/share/icons/hicolor/${size}/apps
  convert -resize $size usr/share/pixmaps/qjackctl.png \
    usr/share/icons/hicolor/${size}/apps/qjackctl.png
done
rm -fr usr/share/pixmaps
#
sed -i "s/^Icon=\(.*\)$/Icon=qjackctl/" usr/share/applications/qjackctl.desktop
# 
# create the slack-desc
#       |----handy-ruler------------------------------------------------------|
cat <<EOF > install/slack-desc
qjackctl: Qjackctl (A Qt4 application to control the JACK sound server daemon)
qjackctl:
qjackctl: Provides a simple GUI dialog for setting several JACK daemon
qjackctl: parameters, which are properly saved between sessions, and a way
qjackctl: control of the status of the audio server daemon.
qjackctl: With time, this primordial interface has become richer by including
qjackctl: a enhanced patchbay and connection control features.
qjackctl: Homepage: http://qjackctl.sourceforge.net
qjackctl:
qjackctl: License: GNU General Public License (GPL)
EOF
cp $CWD/build-qjackctl.sh usr/src/$pkgname

# done so far, make package
fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz

# md5sum & deps
cd $CWD
#requiredbuilder -z $PKG > $PACKAGE.dep
echo $PKG_DEP >$package.dep
echo "$PKG_SRC" > $package.src
md5sum ./$package.txz > $package.md5
